CREATE TABLE "iis_bi_reporting"."dim_date_hour" (
	"date_hour_id"        BIGINT        NOT NULL,
	"year_value"          SMALLINT,
	"quarter_value"       TINYINT,
	"month_value"         TINYINT,
	"month_name"          VARCHAR(20),
	"week_of_year"        TINYINT,
	"day_of_month"        TINYINT,
	"day_name"            VARCHAR(225),
	"hour_24"             TINYINT,
	"hour_12"             VARCHAR(8),
	"date_value"          TIMESTAMP,
	"quarter_year"        VARCHAR(7),
	"month_name_year"     VARCHAR(15),
	"year_quarter"        VARCHAR(5),
	"year_month_value"    VARCHAR(7),
	"month_year"          VARCHAR(7),
	"year_month_day_date" DATE,
	"month_day_year_date" VARCHAR(10),
	CONSTRAINT "pkdim_date_hour" PRIMARY KEY ("date_hour_id")
);
CREATE INDEX "idx_date_hour_id" ON "iis_bi_reporting"."dim_date_hour" ("date_hour_id");
CREATE INDEX "idx_date_value" ON "iis_bi_reporting"."dim_date_hour" ("date_value");
CREATE INDEX "idx_day_of_month" ON "iis_bi_reporting"."dim_date_hour" ("day_of_month", "day_name");
CREATE INDEX "idx_hour" ON "iis_bi_reporting"."dim_date_hour" ("hour_24", "hour_12", "date_value");
CREATE INDEX "idx_month" ON "iis_bi_reporting"."dim_date_hour" ("month_value", "month_name");
CREATE INDEX "idx_week_of_year" ON "iis_bi_reporting"."dim_date_hour" ("week_of_year");
CREATE INDEX "idx_year" ON "iis_bi_reporting"."dim_date_hour" ("year_value", "quarter_value");
CREATE TABLE "iis_bi_reporting"."fact_utilization_hourly" (
	"equipment_id"                BIGINT        NOT NULL,
	"equipment_status_id"         BIGINT        NOT NULL,
	"equipment_service_status_id" BIGINT        NOT NULL,
	"assigned_location_id"        BIGINT        NOT NULL,
	"last_known_location_id"      BIGINT        NOT NULL,
	"equipment_owner_id"          BIGINT        NOT NULL,
	"equipment_type_id"           BIGINT        NOT NULL,
	"equipment_model_id"          BIGINT        NOT NULL,
	"equipment_manufacturer_id"   BIGINT        NOT NULL,
	"date_hour_id"                BIGINT        NOT NULL,
	"time_bucket"                 TIMESTAMP,
	"seconds"                     INTEGER,
	"start_time"                  TIMESTAMP,
	"end_time"                    TIMESTAMP,
	"equipment_value"             REAL,
	"equipment_expiration"        TIMESTAMP,
	"is_utilized"                 TINYINT,
	"is_rented"                   TINYINT       DEFAULT 0,
	"rental_expense"              REAL,
	"create_date"                 TIMESTAMP
);
CREATE INDEX "idx_assigned_location_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("assigned_location_id");
CREATE INDEX "idx_date_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("date_hour_id");
CREATE INDEX "idx_date_type_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("date_hour_id", "equipment_type_id");
CREATE INDEX "idx_date_type_owner_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("date_hour_id", "equipment_type_id", "equipment_owner_id");
CREATE INDEX "idx_equipment_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_id");
CREATE INDEX "idx_equipment_svc_status_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_service_status_id");
CREATE INDEX "idx_equipment_type_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_type_id");
CREATE INDEX "idx_lst_known_loc_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("last_known_location_id");
CREATE INDEX "idx_manufacturer_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_manufacturer_id");
CREATE INDEX "idx_model_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_model_id");
CREATE INDEX "idx_owner_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_owner_id");
CREATE INDEX "idx_status_id_fact_utilization_hourly" ON "iis_bi_reporting"."fact_utilization_hourly" ("equipment_status_id");
